@@ -1,6 +1,6 @@
 package File::Tabular::Web; # documentation at bottom of file
 
-our $VERSION = "0.18"; 
+our $VERSION = "0.19"; 
 
 use strict;
 use warnings;
@@ -513,6 +513,10 @@ sub display { # display results in the requested view
                                          : "$self->{app}{name}_$view.tt";
   my $tmpl_name = $self->{cfg}->get("template_$view") || $default_tmpl;
 
+  # override template toolkit's failsafe counter for while loops
+  # in case of download action
+  local $Template::Directive::WHILE_MAX = 50000 if $view eq 'download';
+
   # call that template
   my $body;
   my $vars = {self => $self, found => $self->{results}};
